{% load i18n %}
{% load navactive %}

{% if perms.madc.basic_access %}
    <li class="nav-item">
        <a class="nav-link" href="{% url 'madc:overview' character_id=character_id %}">{% translate "Account Overview" %}</a>
    </li>
{% endif %}

{% if perms.madc.corp_access %}
    <li class="nav-item">
        <a class="nav-link" href="{% url 'madc:corporation_overview' character_id=character_id %}">{% translate "Corporation Overview" %}</a>
    </li>
{% endif %}
