{% extends 'madc/base.html' %}
{% load i18n %}
{% load humanize %}
{% load bootstrap %}

{% block view_block %}
<div class="card-body bg-primary rounded-top d-flex align-items-center">
    <h3 class="me-3">{% translate "Add Doctrine" %}</h3>
</div>
<div class="card-body rounded-bottom">
    <form class="form w-25" method="post" action="{% url 'madc:ajax_doctrine' %}">
        {% csrf_token %}
        <fieldset class="skill-checker-form">
            {{ forms.skilllist|bootstrap }}
        </fieldset>
        <input type="submit" value="{% translate 'Submit' %}" class="btn col-md-12 btn-primary" />
    </form>
</div>
{% endblock %}

{% block extra_javascript %}
{% endblock %}

{% block extra_css %}
{% endblock %}

{% block extra_script %}
{% endblock %}
